@@ -8,7 +8,8 @@ echo 'preliminary thisdir='$thisdir
 pkgDIR=`dirname $thisdir`
 pkg=`basename $pkgDIR`
 echo '  -->        pkgDIR='$pkgDIR' ; pkg='$pkg
-cd `R-devel RHOME`/po
+echo ''; echo '## FIXME ## use new Scheme from R 2.16.x on'
+cd `R-patched RHOME`/po
 make pkg-update PKG=$pkg PKGDIR=$pkgDIR
 echo 'end{make pkg-update}' ; echo ''
 echo 'Test with (e.g.)'
@@ -16,4 +17,4 @@ echo '       LANGUAGE=de R --no-environ --no-save' ; echo ''
 echo 'and then something like'
 echo '       Matrix(1:6, 2,3) %*% Matrix(1:4, 2)'; echo ''
 echo 'Commit with something like'
-echo "       svn ci -m'translation updates'  po  inst/po"; echo ''
\ No newline at end of file
+echo "       svn ci -m'translation updates'  po  inst/po"; echo ''
