@@ -3,12 +3,11 @@
 /* ========================================================================== */
 
 /* -----------------------------------------------------------------------------
- * CHOLMOD/Include/cholmod_cholesky.h.  Version 1.2.
- * Copyright (C) 2005-2006, Timothy A. Davis
+ * CHOLMOD/Include/cholmod_cholesky.h. Copyright (C) 2005-2006, Timothy A. Davis
  * CHOLMOD/Include/cholmod_cholesky.h is licensed under Version 2.1 of the GNU
  * Lesser General Public License.  See lesser.txt for a text of the license.
  * CHOLMOD is also available under other licenses; contact authors for details.
- * http://www.cise.ufl.edu/research/sparse
+ * http://www.suitesparse.com
  * -------------------------------------------------------------------------- */
 
 /* CHOLMOD Cholesky module.
@@ -103,8 +102,27 @@ cholmod_factor *cholmod_analyze_p
     cholmod_common *Common
 ) ;
 
-cholmod_factor *cholmod_l_analyze_p (cholmod_sparse *, UF_long *, UF_long *,
-    size_t, cholmod_common *) ;
+cholmod_factor *cholmod_l_analyze_p (cholmod_sparse *, SuiteSparse_long *,
+    SuiteSparse_long *, size_t, cholmod_common *) ;
+
+/* -------------------------------------------------------------------------- */
+/* cholmod_analyze_p2:  analyze for sparse Cholesky or sparse QR */
+/* -------------------------------------------------------------------------- */
+
+cholmod_factor *cholmod_analyze_p2
+(
+    /* ---- input ---- */
+    int for_cholesky,   /* if TRUE, then analyze for Cholesky; else for QR */
+    cholmod_sparse *A,	/* matrix to order and analyze */
+    int *UserPerm,	/* user-provided permutation, size A->nrow */
+    int *fset,		/* subset of 0:(A->ncol)-1 */
+    size_t fsize,	/* size of fset */
+    /* --------------- */
+    cholmod_common *Common
+) ;
+
+cholmod_factor *cholmod_l_analyze_p2 (int, cholmod_sparse *, SuiteSparse_long *,
+    SuiteSparse_long *, size_t, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_factorize:  simplicial or supernodal Cholesky factorization */
@@ -146,8 +164,8 @@ int cholmod_factorize_p
     cholmod_common *Common
 ) ;
 
-int cholmod_l_factorize_p (cholmod_sparse *, double *, UF_long *, size_t,
-    cholmod_factor *, cholmod_common *) ;
+int cholmod_l_factorize_p (cholmod_sparse *, double *, SuiteSparse_long *,
+    size_t, cholmod_factor *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_solve:  solve a linear system (simplicial or supernodal) */
@@ -211,7 +229,7 @@ int cholmod_etree
     cholmod_common *Common
 ) ;
 
-int cholmod_l_etree (cholmod_sparse *, UF_long *, cholmod_common *) ;
+int cholmod_l_etree (cholmod_sparse *, SuiteSparse_long *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_rowcolcounts: compute the row/column counts of L */
@@ -239,8 +257,10 @@ int cholmod_rowcolcounts
     cholmod_common *Common
 ) ;
 
-int cholmod_l_rowcolcounts (cholmod_sparse *, UF_long *, size_t, UF_long *,
-    UF_long *, UF_long *, UF_long *, UF_long *, UF_long *, cholmod_common *) ;
+int cholmod_l_rowcolcounts (cholmod_sparse *, SuiteSparse_long *, size_t,
+    SuiteSparse_long *, SuiteSparse_long *, SuiteSparse_long *,
+    SuiteSparse_long *, SuiteSparse_long *, SuiteSparse_long *,
+    cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_analyze_ordering:  analyze a fill-reducing ordering */
@@ -265,8 +285,9 @@ int cholmod_analyze_ordering
     cholmod_common *Common
 ) ;
 
-int cholmod_l_analyze_ordering (cholmod_sparse *, int, UF_long *, UF_long *,
-    size_t, UF_long *, UF_long *, UF_long *, UF_long *, UF_long *,
+int cholmod_l_analyze_ordering (cholmod_sparse *, int, SuiteSparse_long *,
+    SuiteSparse_long *, size_t, SuiteSparse_long *, SuiteSparse_long *,
+    SuiteSparse_long *, SuiteSparse_long *, SuiteSparse_long *,
     cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
@@ -288,8 +309,8 @@ int cholmod_amd
     cholmod_common *Common
 ) ;
 
-int cholmod_l_amd (cholmod_sparse *, UF_long *, size_t, UF_long *,
-    cholmod_common *) ;
+int cholmod_l_amd (cholmod_sparse *, SuiteSparse_long *, size_t,
+    SuiteSparse_long *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_colamd:  order using COLAMD */
@@ -311,8 +332,8 @@ int cholmod_colamd
     cholmod_common *Common
 ) ;
 
-int cholmod_l_colamd (cholmod_sparse *, UF_long *, size_t, int, UF_long *,
-    cholmod_common *) ;
+int cholmod_l_colamd (cholmod_sparse *, SuiteSparse_long *, size_t, int,
+    SuiteSparse_long *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_rowfac:  incremental simplicial factorization */
@@ -364,7 +385,8 @@ int cholmod_rowfac_mask
 ) ;
 
 int cholmod_l_rowfac_mask (cholmod_sparse *, cholmod_sparse *, double *, size_t,
-    size_t, UF_long *, UF_long *, cholmod_factor *, cholmod_common *) ;
+    size_t, SuiteSparse_long *, SuiteSparse_long *, cholmod_factor *,
+    cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_row_subtree:  find the nonzero pattern of a row of L */
@@ -387,7 +409,7 @@ int cholmod_row_subtree
 ) ;
 
 int cholmod_l_row_subtree (cholmod_sparse *, cholmod_sparse *, size_t,
-    UF_long *, cholmod_sparse *, cholmod_common *) ;
+    SuiteSparse_long *, cholmod_sparse *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
 /* cholmod_row_lsubtree:  find the nonzero pattern of a row of L */
@@ -410,7 +432,7 @@ int cholmod_row_lsubtree
     cholmod_common *Common
 ) ;
 
-int cholmod_l_row_lsubtree (cholmod_sparse *, UF_long *, size_t,
+int cholmod_l_row_lsubtree (cholmod_sparse *, SuiteSparse_long *, size_t,
     size_t, cholmod_factor *, cholmod_sparse *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
@@ -437,7 +459,7 @@ int cholmod_resymbol
     cholmod_common *Common
 ) ;
 
-int cholmod_l_resymbol (cholmod_sparse *, UF_long *, size_t, int,
+int cholmod_l_resymbol (cholmod_sparse *, SuiteSparse_long *, size_t, int,
     cholmod_factor *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
@@ -460,7 +482,7 @@ int cholmod_resymbol_noperm
     cholmod_common *Common
 ) ;
 
-int cholmod_l_resymbol_noperm (cholmod_sparse *, UF_long *, size_t, int,
+int cholmod_l_resymbol_noperm (cholmod_sparse *, SuiteSparse_long *, size_t, int,
     cholmod_factor *, cholmod_common *) ;
 
 /* -------------------------------------------------------------------------- */
@@ -481,7 +503,7 @@ double cholmod_l_rcond (cholmod_factor *, cholmod_common *) ;
 /* cholmod_postorder: Compute the postorder of a tree */
 /* -------------------------------------------------------------------------- */
 
-UF_long cholmod_postorder	/* return # of nodes postordered */
+SuiteSparse_long cholmod_postorder	/* return # of nodes postordered */
 (
     /* ---- input ---- */
     int *Parent,	/* size n. Parent [j] = p if p is the parent of j */
@@ -493,7 +515,7 @@ UF_long cholmod_postorder	/* return # of nodes postordered */
     cholmod_common *Common
 ) ;
 
-UF_long cholmod_l_postorder (UF_long *, size_t, UF_long *, UF_long *,
-    cholmod_common *) ;
+SuiteSparse_long cholmod_l_postorder (SuiteSparse_long *, size_t,
+    SuiteSparse_long *, SuiteSparse_long *, cholmod_common *) ;
 
 #endif
