@@ -2,6 +2,7 @@ library(Matrix)
 source(system.file("test-tools.R", package = "Matrix"))# identical3(),
                                         # further  checkMatrix(), etc
 if(interactive()) options(error = recover)
+cat("doExtras:",doExtras,"\n")
 
 setClass("myDGC", contains = "dgCMatrix")
 M <- new("myDGC", as(Matrix(c(-2:4, rep(0,9)), 4), "CsparseMatrix"))
@@ -54,7 +55,7 @@ for(n in allCl) {
     else {
         cat("\"Actual\" class", .dq(n),":\n")
         x <- new(n)
-        for(m in allCl)
+        if(doExtras) for(m in allCl)
             if(classCanCoerce(n,m)) {
                 ext <- extends(n, m)
                 if(ext) {
@@ -150,8 +151,8 @@ tstMatrixClass <-
     ## ----------------------------------------------------------------------
     ## Author: Martin Maechler
 
-    ## This is sfsmisc::bl.string():
-    bl.string <- function (no) paste(rep(" ", no), collapse = "")
+    ## from pkg sfsmisc :
+    bl.string <- function(no) sprintf("%*s", no, "")
 
     ## Compute a few things only once :
     mM <- as(mM, "dgeMatrix")
